# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Added

## [v0.1.2] - 2020-10-10

### Added

- Pin down `google-cloud-kms` to `1.4.0`, and update `pip cache` for tests ([#11])
- chore: Fix setup.py description and README.md release instructions ([#8])
- Add template for PRs and commits

## [v0.1.1] - 2019-12-24

### Added

- Use `LOGLEVEL` environment variable to set log level in the cli ([#1])

## [v0.1.0] - 2019-12-18

### Added

- Initial release: support for AWS KMS + Parameter Store and GCP KMS + Datastore

[unreleased]: https://github.com/tra-sg/discreetly/compare/v0.1.2...HEAD
[v0.1.1]: https://github.com/tra-sg/discreetly/releases/tag/v0.1.2
[v0.1.1]: https://github.com/tra-sg/discreetly/releases/tag/v0.1.1
[v0.1.0]: https://github.com/tra-sg/discreetly/releases/tag/v0.1.0
[#1]: https://github.com/tra-sg/discreetly/issues/1
[#8]: https://github.com/tra-sg/discreetly/pull/8/
[#11]: https://github.com/tra-sg/discreetly/pull/11/
